[SCM] WebKit Debian packaging branch, debian/unstable, updated. debian/1.1.15-1-40151-g37bb677

cblu cblu at 268f45cc-cd09-0410-ab3c-d52691b4dbfc
Sat Sep 26 07:21:27 UTC 2009


The following commit has been merged in the debian/unstable branch:
commit c35373dbc4b9e01101a7d56fbdb47a0591d2325f
Author: cblu <cblu at 268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Thu Jan 23 20:23:46 2003 +0000

    	Replaced the paint phase constants with the PaintAction enum. Added PaintActionSelection as a paint action. This will eventually allow us to only paint selected objects. This is needed for the text dragging image.
    
            Reviewed by dave.
    
            * khtml/rendering/render_box.cpp:
            (RenderBox::paint):
            * khtml/rendering/render_box.h:
            * khtml/rendering/render_flow.cpp:
            (RenderFlow::paint):
            (RenderFlow::paintObject):
            (RenderFlow::paintFloats):
            * khtml/rendering/render_flow.h:
            * khtml/rendering/render_html.cpp:
            (RenderHtml::paint):
            * khtml/rendering/render_html.h:
            * khtml/rendering/render_image.cpp:
            (RenderImage::paintObject):
            * khtml/rendering/render_image.h:
            * khtml/rendering/render_layer.cpp:
            (RenderLayer::paint):
            * khtml/rendering/render_list.cpp:
            (RenderListItem::paint):
            (RenderListItem::paintObject):
            (RenderListMarker::paint):
            (RenderListMarker::paintObject):
            * khtml/rendering/render_list.h:
            * khtml/rendering/render_object.cpp:
            (RenderObject::paint):
            * khtml/rendering/render_object.h:
            * khtml/rendering/render_replaced.cpp:
            (RenderReplaced::paint):
            (RenderWidget::paintObject):
            * khtml/rendering/render_replaced.h:
            * khtml/rendering/render_root.cpp:
            (RenderRoot::paint):
            (RenderRoot::paintObject):
            * khtml/rendering/render_root.h:
            * khtml/rendering/render_table.cpp:
            (RenderTable::paint):
            (RenderTableSection::paint):
            (RenderTableCell::paint):
            * khtml/rendering/render_table.h:
            * khtml/rendering/render_text.cpp:
            (RenderText::paintObject):
            (RenderText::paint):
            * khtml/rendering/render_text.h:
    
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@3424 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebCore/ChangeLog-2003-10-25 b/WebCore/ChangeLog-2003-10-25
index 889083f..a1fc9d9 100644
--- a/WebCore/ChangeLog-2003-10-25
+++ b/WebCore/ChangeLog-2003-10-25
@@ -1,3 +1,52 @@
+2003-01-23  Chris Blumenberg  <cblu at apple.com>
+
+	Replaced the paint phase constants with the PaintAction enum. Added PaintActionSelection as a paint action. This will eventually allow us to only paint selected objects. This is needed for the text dragging image.
+
+        Reviewed by dave.
+
+        * khtml/rendering/render_box.cpp:
+        (RenderBox::paint):
+        * khtml/rendering/render_box.h:
+        * khtml/rendering/render_flow.cpp:
+        (RenderFlow::paint):
+        (RenderFlow::paintObject):
+        (RenderFlow::paintFloats):
+        * khtml/rendering/render_flow.h:
+        * khtml/rendering/render_html.cpp:
+        (RenderHtml::paint):
+        * khtml/rendering/render_html.h:
+        * khtml/rendering/render_image.cpp:
+        (RenderImage::paintObject):
+        * khtml/rendering/render_image.h:
+        * khtml/rendering/render_layer.cpp:
+        (RenderLayer::paint):
+        * khtml/rendering/render_list.cpp:
+        (RenderListItem::paint):
+        (RenderListItem::paintObject):
+        (RenderListMarker::paint):
+        (RenderListMarker::paintObject):
+        * khtml/rendering/render_list.h:
+        * khtml/rendering/render_object.cpp:
+        (RenderObject::paint):
+        * khtml/rendering/render_object.h:
+        * khtml/rendering/render_replaced.cpp:
+        (RenderReplaced::paint):
+        (RenderWidget::paintObject):
+        * khtml/rendering/render_replaced.h:
+        * khtml/rendering/render_root.cpp:
+        (RenderRoot::paint):
+        (RenderRoot::paintObject):
+        * khtml/rendering/render_root.h:
+        * khtml/rendering/render_table.cpp:
+        (RenderTable::paint):
+        (RenderTableSection::paint):
+        (RenderTableCell::paint):
+        * khtml/rendering/render_table.h:
+        * khtml/rendering/render_text.cpp:
+        (RenderText::paintObject):
+        (RenderText::paint):
+        * khtml/rendering/render_text.h:
+
 2003-01-23  David Hyatt  <hyatt at apple.com>
 
 	Fix for 3147995, empty <li> tags don't render bullets.
diff --git a/WebCore/ChangeLog-2005-08-23 b/WebCore/ChangeLog-2005-08-23
index 889083f..a1fc9d9 100644
--- a/WebCore/ChangeLog-2005-08-23
+++ b/WebCore/ChangeLog-2005-08-23
@@ -1,3 +1,52 @@
+2003-01-23  Chris Blumenberg  <cblu at apple.com>
+
+	Replaced the paint phase constants with the PaintAction enum. Added PaintActionSelection as a paint action. This will eventually allow us to only paint selected objects. This is needed for the text dragging image.
+
+        Reviewed by dave.
+
+        * khtml/rendering/render_box.cpp:
+        (RenderBox::paint):
+        * khtml/rendering/render_box.h:
+        * khtml/rendering/render_flow.cpp:
+        (RenderFlow::paint):
+        (RenderFlow::paintObject):
+        (RenderFlow::paintFloats):
+        * khtml/rendering/render_flow.h:
+        * khtml/rendering/render_html.cpp:
+        (RenderHtml::paint):
+        * khtml/rendering/render_html.h:
+        * khtml/rendering/render_image.cpp:
+        (RenderImage::paintObject):
+        * khtml/rendering/render_image.h:
+        * khtml/rendering/render_layer.cpp:
+        (RenderLayer::paint):
+        * khtml/rendering/render_list.cpp:
+        (RenderListItem::paint):
+        (RenderListItem::paintObject):
+        (RenderListMarker::paint):
+        (RenderListMarker::paintObject):
+        * khtml/rendering/render_list.h:
+        * khtml/rendering/render_object.cpp:
+        (RenderObject::paint):
+        * khtml/rendering/render_object.h:
+        * khtml/rendering/render_replaced.cpp:
+        (RenderReplaced::paint):
+        (RenderWidget::paintObject):
+        * khtml/rendering/render_replaced.h:
+        * khtml/rendering/render_root.cpp:
+        (RenderRoot::paint):
+        (RenderRoot::paintObject):
+        * khtml/rendering/render_root.h:
+        * khtml/rendering/render_table.cpp:
+        (RenderTable::paint):
+        (RenderTableSection::paint):
+        (RenderTableCell::paint):
+        * khtml/rendering/render_table.h:
+        * khtml/rendering/render_text.cpp:
+        (RenderText::paintObject):
+        (RenderText::paint):
+        * khtml/rendering/render_text.h:
+
 2003-01-23  David Hyatt  <hyatt at apple.com>
 
 	Fix for 3147995, empty <li> tags don't render bullets.
diff --git a/WebCore/khtml/rendering/render_box.cpp b/WebCore/khtml/rendering/render_box.cpp
index bf6d53b..84f66f7 100644
--- a/WebCore/khtml/rendering/render_box.cpp
+++ b/WebCore/khtml/rendering/render_box.cpp
@@ -153,7 +153,7 @@ int RenderBox::height() const
 // --------------------- painting stuff -------------------------------
 
 void RenderBox::paint(QPainter *p, int _x, int _y, int _w, int _h,
-                      int _tx, int _ty, int paintPhase)
+                      int _tx, int _ty, PaintAction paintAction)
 {
     _tx += m_x;
     _ty += m_y;
@@ -162,7 +162,7 @@ void RenderBox::paint(QPainter *p, int _x, int _y, int _w, int _h,
     RenderObject *child = firstChild();
     while(child != 0)
     {
-        child->paint(p, _x, _y, _w, _h, _tx, _ty, paintPhase);
+        child->paint(p, _x, _y, _w, _h, _tx, _ty, paintAction);
         child = child->nextSibling();
     }
 }
diff --git a/WebCore/khtml/rendering/render_box.h b/WebCore/khtml/rendering/render_box.h
index 659ec3e..faed5bd 100644
--- a/WebCore/khtml/rendering/render_box.h
+++ b/WebCore/khtml/rendering/render_box.h
@@ -48,7 +48,7 @@ public:
 
     virtual void setStyle(RenderStyle *style);
     virtual void paint(QPainter *p, int _x, int _y, int _w, int _h,
-                       int _tx, int _ty, int paintPhase);
+                       int _tx, int _ty, PaintAction paintAction);
 
     virtual void close();
 
diff --git a/WebCore/khtml/rendering/render_flow.cpp b/WebCore/khtml/rendering/render_flow.cpp
index 0b08a84..430c4de 100644
--- a/WebCore/khtml/rendering/render_flow.cpp
+++ b/WebCore/khtml/rendering/render_flow.cpp
@@ -125,7 +125,7 @@ RenderFlow::~RenderFlow()
 }
 
 void RenderFlow::paint(QPainter *p, int _x, int _y, int _w, int _h,
-                       int _tx, int _ty, int paintPhase)
+                       int _tx, int _ty, PaintAction paintAction)
 {
 
 #ifdef DEBUG_LAYOUT
@@ -150,11 +150,11 @@ void RenderFlow::paint(QPainter *p, int _x, int _y, int _w, int _h,
         }
     }
 
-    paintObject(p, _x, _y, _w, _h, _tx, _ty, paintPhase);
+    paintObject(p, _x, _y, _w, _h, _tx, _ty, paintAction);
 }
 
 void RenderFlow::paintObject(QPainter *p, int _x, int _y,
-                             int _w, int _h, int _tx, int _ty, int paintPhase)
+                             int _w, int _h, int _tx, int _ty, PaintAction paintAction)
 {
 
 #ifdef DEBUG_LAYOUT
@@ -162,7 +162,7 @@ void RenderFlow::paintObject(QPainter *p, int _x, int _y,
 #endif
     
     // 1. paint background, borders etc
-    if (paintPhase == BACKGROUND_PHASE && 
+    if (paintAction == PaintActionBackground && 
         shouldPaintBackgroundOrBorder() && !isInline() && style()->visibility() == VISIBLE )
         paintBoxDecorations(p, _x, _y, _w, _h, _tx, _ty);
 
@@ -171,15 +171,15 @@ void RenderFlow::paintObject(QPainter *p, int _x, int _y,
     while(child != 0)
     {
         if(!child->layer() && !child->isFloating())
-            child->paint(p, _x, _y, _w, _h, _tx, _ty, paintPhase);
+            child->paint(p, _x, _y, _w, _h, _tx, _ty, paintAction);
         child = child->nextSibling();
     }
 
     // 3. paint floats.
-    if (paintPhase == FLOAT_PHASE)
+    if (paintAction == PaintActionFloat)
         paintFloats(p, _x, _y, _w, _h, _tx, _ty);
     
-    if (paintPhase == BACKGROUND_PHASE &&
+    if (paintAction == PaintActionBackground &&
         !isInline() && !childrenInline() && style()->outlineWidth())
         paintOutline(p, _tx, _ty, width(), height(), style());
 
@@ -210,15 +210,15 @@ void RenderFlow::paintFloats(QPainter *p, int _x, int _y,
             r->node->paint(p, _x, _y, _w, _h, 
                            _tx + r->left - r->node->xPos() + r->node->marginLeft(), 
                            _ty + r->startY - r->node->yPos() + r->node->marginTop(),
-                           BACKGROUND_PHASE);
+                           PaintActionBackground);
             r->node->paint(p, _x, _y, _w, _h, 
                            _tx + r->left - r->node->xPos() + r->node->marginLeft(), 
                            _ty + r->startY - r->node->yPos() + r->node->marginTop(),
-                           FLOAT_PHASE);
+                           PaintActionFloat);
             r->node->paint(p, _x, _y, _w, _h, 
                            _tx + r->left - r->node->xPos() + r->node->marginLeft(), 
                            _ty + r->startY - r->node->yPos() + r->node->marginTop(), 
-                           FOREGROUND_PHASE);
+                           PaintActionForeground);
         }
     }
 }
diff --git a/WebCore/khtml/rendering/render_flow.h b/WebCore/khtml/rendering/render_flow.h
index d3b0375..1b035a8 100644
--- a/WebCore/khtml/rendering/render_flow.h
+++ b/WebCore/khtml/rendering/render_flow.h
@@ -91,9 +91,9 @@ public:
     // overrides RenderObject
 
     virtual void paint(QPainter *, int x, int y, int w, int h,
-                       int tx, int ty, int paintPhase);
+                       int tx, int ty, PaintAction paintAction);
     virtual void paintObject(QPainter *, int x, int y, int w, int h,
-                             int tx, int ty, int paintPhase);
+                             int tx, int ty, PaintAction paintAction);
     void paintFloats(QPainter *p, int _x, int _y,
                      int _w, int _h, int _tx, int _ty);
             
diff --git a/WebCore/khtml/rendering/render_html.cpp b/WebCore/khtml/rendering/render_html.cpp
index 40ed33a..7a01687 100644
--- a/WebCore/khtml/rendering/render_html.cpp
+++ b/WebCore/khtml/rendering/render_html.cpp
@@ -48,13 +48,13 @@ void RenderHtml::setStyle(RenderStyle *style)
 }
 
 void RenderHtml::paint(QPainter *p, int _x, int _y, int _w, int _h, int _tx, int _ty,
-                       int paintPhase)
+                       PaintAction paintAction)
 {
     _tx += m_x;
     _ty += m_y;
 
     //kdDebug(0) << "html:paint " << _tx << "/" << _ty << endl;
-    paintObject(p, _x, _y, _w, _h, _tx, _ty, paintPhase);
+    paintObject(p, _x, _y, _w, _h, _tx, _ty, paintAction);
 }
 
 void RenderHtml::paintBoxDecorations(QPainter *p,int, int _y,
diff --git a/WebCore/khtml/rendering/render_html.h b/WebCore/khtml/rendering/render_html.h
index 0bc7205..bd938f2 100644
--- a/WebCore/khtml/rendering/render_html.h
+++ b/WebCore/khtml/rendering/render_html.h
@@ -43,7 +43,7 @@ namespace khtml {
 
 	virtual bool isHtml() const { return true; }
 	virtual void setStyle(RenderStyle *style);
-	virtual void paint(QPainter *, int x, int y, int w, int h, int tx, int ty, int paintPhase);
+	virtual void paint(QPainter *, int x, int y, int w, int h, int tx, int ty, PaintAction paintAction);
 	virtual void repaint(bool immediate=false);
 	virtual void layout();
     virtual short containingBlockWidth() const;
diff --git a/WebCore/khtml/rendering/render_image.cpp b/WebCore/khtml/rendering/render_image.cpp
index 954e809..ec7bd19 100644
--- a/WebCore/khtml/rendering/render_image.cpp
+++ b/WebCore/khtml/rendering/render_image.cpp
@@ -180,9 +180,9 @@ void RenderImage::setPixmap( const QPixmap &p, const QRect& r, CachedImage *o)
     }
 }
 
-void RenderImage::paintObject(QPainter *p, int /*_x*/, int /*_y*/, int /*_w*/, int /*_h*/, int _tx, int _ty, int paintPhase)
+void RenderImage::paintObject(QPainter *p, int /*_x*/, int /*_y*/, int /*_w*/, int /*_h*/, int _tx, int _ty, PaintAction paintAction)
 {
-    if (paintPhase != FOREGROUND_PHASE)
+    if (paintAction != PaintActionForeground)
         return;
         
     int cWidth = contentWidth();
diff --git a/WebCore/khtml/rendering/render_image.h b/WebCore/khtml/rendering/render_image.h
index d28f6b0..1e6831e 100644
--- a/WebCore/khtml/rendering/render_image.h
+++ b/WebCore/khtml/rendering/render_image.h
@@ -46,7 +46,7 @@ public:
     virtual bool isRendered() const { return true; }
     virtual bool isImage() const { return false; }
     
-    virtual void paintObject( QPainter *p, int /*x*/, int /*y*/, int /*w*/, int /*h*/, int tx, int ty, int paintPhase);
+    virtual void paintObject( QPainter *p, int /*x*/, int /*y*/, int /*w*/, int /*h*/, int tx, int ty, PaintAction paintAction);
 
     virtual void layout();
 
diff --git a/WebCore/khtml/rendering/render_layer.cpp b/WebCore/khtml/rendering/render_layer.cpp
index aa8d542..40d2b3b 100644
--- a/WebCore/khtml/rendering/render_layer.cpp
+++ b/WebCore/khtml/rendering/render_layer.cpp
@@ -340,15 +340,15 @@ RenderLayer::paint(QPainter *p, int x, int y, int w, int h)
         elt->layer->renderer()->paint(p, x, y, w, h,
                                       elt->absBounds.x() - elt->layer->renderer()->xPos(),
                                       elt->absBounds.y() - elt->layer->renderer()->yPos(),
-                                      BACKGROUND_PHASE);
+                                      PaintActionBackground);
         elt->layer->renderer()->paint(p, x, y, w, h,
                                       elt->absBounds.x() - elt->layer->renderer()->xPos(),
                                       elt->absBounds.y() - elt->layer->renderer()->yPos(),
-                                      FLOAT_PHASE);
+                                      PaintActionFloat);
         elt->layer->renderer()->paint(p, x, y, w, h,
                                       elt->absBounds.x() - elt->layer->renderer()->xPos(),
                                       elt->absBounds.y() - elt->layer->renderer()->yPos(),
-                                      FOREGROUND_PHASE);
+                                      PaintActionForeground);
     }
     
     if (currRect != paintRect)
diff --git a/WebCore/khtml/rendering/render_list.cpp b/WebCore/khtml/rendering/render_list.cpp
index 44b3c4f..cd58690 100644
--- a/WebCore/khtml/rendering/render_list.cpp
+++ b/WebCore/khtml/rendering/render_list.cpp
@@ -253,7 +253,7 @@ void RenderListItem::layout( )
 }
 
 void RenderListItem::paint(QPainter *p, int _x, int _y, int _w, int _h,
-                           int _tx, int _ty, int paintPhase)
+                           int _tx, int _ty, PaintAction paintAction)
 {
     if ( !m_height )
         return;
@@ -261,15 +261,15 @@ void RenderListItem::paint(QPainter *p, int _x, int _y, int _w, int _h,
 #ifdef DEBUG_LAYOUT
     kdDebug( 6040 ) << nodeName().string() << "(LI)::paint()" << endl;
 #endif
-    RenderFlow::paint(p, _x, _y, _w, _h, _tx, _ty, paintPhase);
+    RenderFlow::paint(p, _x, _y, _w, _h, _tx, _ty, paintAction);
 }
 
 void RenderListItem::paintObject(QPainter *p, int _x, int _y,
-                                    int _w, int _h, int _tx, int _ty, int paintPhase)
+                                    int _w, int _h, int _tx, int _ty, PaintAction paintAction)
 {
     // ### this should scale with the font size in the body... possible?
     //m_marker->printIcon(p, _tx, _ty);
-    RenderFlow::paintObject(p, _x, _y, _w, _h, _tx, _ty, paintPhase);
+    RenderFlow::paintObject(p, _x, _y, _w, _h, _tx, _ty, paintAction);
 }
 
 // -----------------------------------------------------------
@@ -307,9 +307,9 @@ void RenderListMarker::setStyle(RenderStyle *s)
 
 
 void RenderListMarker::paint(QPainter *p, int _x, int _y, int _w, int _h,
-                             int _tx, int _ty, int paintPhase)
+                             int _tx, int _ty, PaintAction paintAction)
 {
-    if (paintPhase != FOREGROUND_PHASE)
+    if (paintAction != PaintActionForeground)
         return;
     
     if (style()->visibility() != VISIBLE)  return;
@@ -323,11 +323,11 @@ void RenderListMarker::paint(QPainter *p, int _x, int _y, int _w, int _h,
     if(shouldPaintBackgroundOrBorder()) 
         paintBoxDecorations(p, _x, _y, _w, _h, _tx, _ty);
 
-    paintObject(p, _x, _y, _w, _h, _tx, _ty, paintPhase);
+    paintObject(p, _x, _y, _w, _h, _tx, _ty, paintAction);
 }
 
 void RenderListMarker::paintObject(QPainter *p, int, int _y,
-                                    int, int _h, int _tx, int _ty, int paintPhase)
+                                    int, int _h, int _tx, int _ty, PaintAction paintAction)
 {
     if (style()->visibility() != VISIBLE) return;
 
diff --git a/WebCore/khtml/rendering/render_list.h b/WebCore/khtml/rendering/render_list.h
index 9a5522a..823ce1e 100644
--- a/WebCore/khtml/rendering/render_list.h
+++ b/WebCore/khtml/rendering/render_list.h
@@ -49,9 +49,9 @@ public:
     // list-style-position: inside
 
     virtual void paint(QPainter *p, int x, int y, int w, int h,
-                       int xoff, int yoff, int paintPhase);
+                       int xoff, int yoff, PaintAction paintAction);
     virtual void paintObject(QPainter *p, int x, int y, int w, int h,
-                             int xoff, int yoff, int paintPhase);
+                             int xoff, int yoff, PaintAction paintAction);
     virtual void layout( );
     virtual void calcMinMaxWidth();
 
@@ -95,9 +95,9 @@ public:
     void calcListValue();
     
     virtual void paint(QPainter *p, int x, int y, int w, int h,
-                       int xoff, int yoff, int paintPhase);
+                       int xoff, int yoff, PaintAction paintAction);
     virtual void paintObject(QPainter *p, int x, int y, int w, int h,
-                       int xoff, int yoff, int paintPhase);
+                       int xoff, int yoff, PaintAction paintAction);
 
     virtual void layout( );
     virtual void calcMinMaxWidth();
diff --git a/WebCore/khtml/rendering/render_object.cpp b/WebCore/khtml/rendering/render_object.cpp
index 35bdbb1..9458b4b 100644
--- a/WebCore/khtml/rendering/render_object.cpp
+++ b/WebCore/khtml/rendering/render_object.cpp
@@ -723,9 +723,9 @@ void RenderObject::paintOutline(QPainter *p, int _tx, int _ty, int w, int h, con
 }
 
 void RenderObject::paint(QPainter *p, int x, int y, int w, int h, int tx, int ty,
-                         int paintPhase)
+                         PaintAction paintAction)
 {
-    paintObject(p, x, y, w, h, tx, ty, paintPhase);
+    paintObject(p, x, y, w, h, tx, ty, paintAction);
 }
 
 void RenderObject::repaintRectangle(int x, int y, int w, int h, bool immediate, bool f)
diff --git a/WebCore/khtml/rendering/render_replaced.cpp b/WebCore/khtml/rendering/render_replaced.cpp
index d6d81fa..49da097 100644
--- a/WebCore/khtml/rendering/render_replaced.cpp
+++ b/WebCore/khtml/rendering/render_replaced.cpp
@@ -54,9 +54,9 @@ RenderReplaced::RenderReplaced(DOM::NodeImpl* node)
 }
 
 void RenderReplaced::paint(QPainter *p, int _x, int _y, int _w, int _h,
-                           int _tx, int _ty, int paintPhase)
+                           int _tx, int _ty, PaintAction paintAction)
 {
-    if (paintPhase != FOREGROUND_PHASE)
+    if (paintAction != PaintActionForeground)
         return;
         
     // not visible or nont even once layouted?
@@ -71,7 +71,7 @@ void RenderReplaced::paint(QPainter *p, int _x, int _y, int _w, int _h,
     if(shouldPaintBackgroundOrBorder()) 
         paintBoxDecorations(p, _x, _y, _w, _h, _tx, _ty);
 
-    paintObject(p, _x, _y, _w, _h, _tx, _ty, paintPhase);
+    paintObject(p, _x, _y, _w, _h, _tx, _ty, paintAction);
 }
 
 void RenderReplaced::calcMinMaxWidth()
@@ -237,13 +237,13 @@ void RenderWidget::setStyle(RenderStyle *_style)
 
 #if APPLE_CHANGES
 void RenderWidget::paintObject(QPainter *p, int x, int y, int width, int height, int _tx, int _ty,
-                               int paintPhase)
+                               PaintAction paintAction)
 #else
 void RenderWidget::paintObject(QPainter* /*p*/, int, int, int, int, int _tx, int _ty,
-                               int paintPhase)
+                               PaintAction paintAction)
 #endif
 {
-    if (!m_widget || !m_view || paintPhase != FOREGROUND_PHASE)
+    if (!m_widget || !m_view || paintAction != PaintActionForeground)
         return;
 
     if (style()->visibility() != VISIBLE) {
diff --git a/WebCore/khtml/rendering/render_replaced.h b/WebCore/khtml/rendering/render_replaced.h
index 8e5eac5..9bdabdf 100644
--- a/WebCore/khtml/rendering/render_replaced.h
+++ b/WebCore/khtml/rendering/render_replaced.h
@@ -44,9 +44,9 @@ public:
     virtual void calcMinMaxWidth();
 
     virtual void paint(QPainter *, int x, int y, int w, int h,
-                       int tx, int ty, int paintPhase);
+                       int tx, int ty, PaintAction paintAction);
     virtual void paintObject(QPainter *p, int x, int y, int w, int h, int tx, int ty,
-                             int paintPhase) = 0;
+                             PaintAction paintAction) = 0;
 
     virtual short intrinsicWidth() const { return m_intrinsicWidth; }
     virtual int intrinsicHeight() const { return m_intrinsicHeight; }
@@ -74,7 +74,7 @@ public:
     virtual void setStyle(RenderStyle *style);
 
     virtual void paintObject(QPainter *p, int x, int y, int w, int h, int tx, int ty,
-                             int paintPhase);
+                             PaintAction paintAction);
 
     virtual bool isWidget() const { return true; };
 
diff --git a/WebCore/khtml/rendering/render_root.cpp b/WebCore/khtml/rendering/render_root.cpp
index 152ffca..a8332f8 100644
--- a/WebCore/khtml/rendering/render_root.cpp
+++ b/WebCore/khtml/rendering/render_root.cpp
@@ -187,26 +187,26 @@ bool RenderRoot::absolutePosition(int &xPos, int &yPos, bool f)
 }
 
 void RenderRoot::paint(QPainter *p, int _x, int _y, int _w, int _h, int _tx, int _ty,
-                       int paintPhase)
+                       PaintAction paintAction)
 {
-    paintObject(p, _x, _y, _w, _h, _tx, _ty, paintPhase);
+    paintObject(p, _x, _y, _w, _h, _tx, _ty, paintAction);
 }
 
 void RenderRoot::paintObject(QPainter *p, int _x, int _y,
-                             int _w, int _h, int _tx, int _ty, int paintPhase)
+                             int _w, int _h, int _tx, int _ty, PaintAction paintAction)
 {
 #ifdef DEBUG_LAYOUT
     kdDebug( 6040 ) << renderName() << "(RenderFlow) " << this << " ::paintObject() w/h = (" << width() << "/" << height() << ")" << endl;
 #endif
     // 1. paint background, borders etc
-    if (paintPhase == BACKGROUND_PHASE && shouldPaintBackgroundOrBorder() && !isInline())
+    if (paintAction == PaintActionBackground && shouldPaintBackgroundOrBorder() && !isInline())
         paintBoxDecorations(p, _x, _y, _w, _h, _tx, _ty);
 
     // 2. paint contents
     RenderObject *child = firstChild();
     while(child != 0) {
         if(!child->layer() && !child->isFloating()) {
-            child->paint(p, _x, _y, _w, _h, _tx, _ty, paintPhase);
+            child->paint(p, _x, _y, _w, _h, _tx, _ty, paintAction);
         }
         child = child->nextSibling();
     }
@@ -218,7 +218,7 @@ void RenderRoot::paintObject(QPainter *p, int _x, int _y,
     }
     
     // 3. paint floats.
-    if (paintPhase == FLOAT_PHASE)
+    if (paintAction == PaintActionFloat)
         paintFloats(p, _x, _y, _w, _h, _tx, _ty);
         
 #ifdef BOX_DEBUG
diff --git a/WebCore/khtml/rendering/render_root.h b/WebCore/khtml/rendering/render_root.h
index d7e9c4b..abebb55 100644
--- a/WebCore/khtml/rendering/render_root.h
+++ b/WebCore/khtml/rendering/render_root.h
@@ -55,9 +55,9 @@ public:
     virtual void repaint(bool immediate=false);
     virtual void repaintRectangle(int x, int y, int w, int h, bool immediate = false, bool f=false);
     virtual void paint(QPainter *, int x, int y, int w, int h, int tx, int ty,
-                       int paintPhase);
+                       PaintAction paintAction);
     void paintObject(QPainter *p, int _x, int _y,
-                     int _w, int _h, int _tx, int _ty, int paintPhase);
+                     int _w, int _h, int _tx, int _ty, PaintAction paintAction);
 
     virtual void setSelection(RenderObject *s, int sp, RenderObject *e, int ep);
     virtual void clearSelection(bool doRepaint=true);
diff --git a/WebCore/khtml/rendering/render_table.cpp b/WebCore/khtml/rendering/render_table.cpp
index d461537..77148e9 100644
--- a/WebCore/khtml/rendering/render_table.cpp
+++ b/WebCore/khtml/rendering/render_table.cpp
@@ -378,7 +378,7 @@ void RenderTable::setCellWidths()
 }
 
 void RenderTable::paint( QPainter *p, int _x, int _y,
-                                  int _w, int _h, int _tx, int _ty, int paintPhase)
+                                  int _w, int _h, int _tx, int _ty, PaintAction paintAction)
 {
     if (!layouted())
         return;
@@ -399,13 +399,13 @@ void RenderTable::paint( QPainter *p, int _x, int _y,
     kdDebug( 6040 ) << "RenderTable::paint(2) " << _tx << "/" << _ty << " (" << _y << "/" << _h << ")" << endl;
 #endif
 
-    if(paintPhase == BACKGROUND_PHASE && style()->visibility() == VISIBLE)
+    if(paintAction == PaintActionBackground && style()->visibility() == VISIBLE)
         paintBoxDecorations(p, _x, _y, _w, _h, _tx, _ty);
 
     RenderObject *child = firstChild();
     while( child ) {
 	if ( child->isTableSection() || child == tCaption )
-	    child->paint( p, _x, _y, _w, _h, _tx, _ty, paintPhase );
+	    child->paint( p, _x, _y, _w, _h, _tx, _ty, paintAction );
 	child = child->nextSibling();
     }
 
@@ -1140,7 +1140,7 @@ int RenderTableSection::layoutRows( int toAdd )
 
 
 void RenderTableSection::paint( QPainter *p, int x, int y, int w, int h,
-				int tx, int ty, int paintPhase)
+				int tx, int ty, PaintAction paintAction)
 {
     unsigned int totalRows = grid.size();
     unsigned int totalCols = table()->columns.size();
@@ -1189,7 +1189,7 @@ void RenderTableSection::paint( QPainter *p, int x, int y, int w, int h,
 #ifdef TABLE_PRINT
 		kdDebug( 6040 ) << "painting cell " << r << "/" << c << endl;
 #endif
-		cell->paint( p, x, y, w, h, tx, ty, paintPhase);
+		cell->paint( p, x, y, w, h, tx, ty, paintAction);
 	    }
 	}
     }
@@ -1487,7 +1487,7 @@ static void outlineBox(QPainter *p, int _tx, int _ty, int w, int h)
 #endif
 
 void RenderTableCell::paint(QPainter *p, int _x, int _y,
-                                       int _w, int _h, int _tx, int _ty, int paintPhase)
+                                       int _w, int _h, int _tx, int _ty, PaintAction paintAction)
 {
 
 #ifdef TABLE_PRINT
@@ -1503,7 +1503,7 @@ void RenderTableCell::paint(QPainter *p, int _x, int _y,
     if(!overhangingContents() && ((_ty-_topExtra > _y + _h)
         || (_ty + m_height+_topExtra+_bottomExtra < _y))) return;
 
-    paintObject(p, _x, _y, _w, _h, _tx, _ty, paintPhase);
+    paintObject(p, _x, _y, _w, _h, _tx, _ty, paintAction);
 
 #ifdef BOX_DEBUG
     ::outlineBox( p, _tx, _ty - _topExtra, width(), height() + borderTopExtra() + borderBottomExtra());
diff --git a/WebCore/khtml/rendering/render_table.h b/WebCore/khtml/rendering/render_table.h
index b057e3f..bc707d8 100644
--- a/WebCore/khtml/rendering/render_table.h
+++ b/WebCore/khtml/rendering/render_table.h
@@ -98,7 +98,7 @@ public:
     virtual int overflowWidth() const { return width(); }
     virtual void addChild(RenderObject *child, RenderObject *beforeChild = 0);
     virtual void paint( QPainter *, int x, int y, int w, int h,
-                        int tx, int ty, int paintPhase);
+                        int tx, int ty, PaintAction paintAction);
     virtual void layout();
     virtual void calcMinMaxWidth();
     virtual void close();
@@ -233,7 +233,7 @@ public:
     }
 
     virtual void paint( QPainter *, int x, int y, int w, int h,
-                        int tx, int ty, int paintPhase);
+                        int tx, int ty, PaintAction paintAction);
 
     int numRows() const { return grid.size(); }
     int getBaseline(int row) {return grid[row].baseLine;}
@@ -333,7 +333,7 @@ public:
     void setCellPercentageHeight(int h);
     
     virtual void paint( QPainter* p, int x, int y,
-                        int w, int h, int tx, int ty, int paintPhase);
+                        int w, int h, int tx, int ty, PaintAction paintAction);
 
     virtual void close();
 
diff --git a/WebCore/khtml/rendering/render_text.cpp b/WebCore/khtml/rendering/render_text.cpp
index ed370c1..0d1f310 100644
--- a/WebCore/khtml/rendering/render_text.cpp
+++ b/WebCore/khtml/rendering/render_text.cpp
@@ -606,7 +606,7 @@ int RenderText::rightmostPosition() const
 }
 
 void RenderText::paintObject(QPainter *p, int /*x*/, int y, int /*w*/, int h,
-                             int tx, int ty, int paintPhase)
+                             int tx, int ty, PaintAction paintAction)
 {
     int ow = style()->outlineWidth();
     RenderStyle* pseudoStyle = style()->getPseudoStyle(RenderStyle::FIRST_LINE);
@@ -788,9 +788,9 @@ void RenderText::paintObject(QPainter *p, int /*x*/, int y, int /*w*/, int h,
 }
 
 void RenderText::paint(QPainter *p, int x, int y, int w, int h,
-                       int tx, int ty, int paintPhase)
+                       int tx, int ty, PaintAction paintAction)
 {
-    if (paintPhase != FOREGROUND_PHASE || style()->visibility() != VISIBLE) 
+    if (paintAction != PaintActionForeground || style()->visibility() != VISIBLE) 
         return;
 
     int s = m_lines.count() - 1;
@@ -800,7 +800,7 @@ void RenderText::paint(QPainter *p, int x, int y, int w, int h,
     if ( ty + m_lines[0]->m_y > y + h + 64 ) return;
     if ( ty + m_lines[s]->m_y + m_lines[s]->m_baseline + m_lineHeight + 64 < y ) return;
 
-    paintObject(p, x, y, w, h, tx, ty, paintPhase);
+    paintObject(p, x, y, w, h, tx, ty, paintAction);
 }
 
 #ifdef APPLE_CHANGES
diff --git a/WebCore/khtml/rendering/render_text.h b/WebCore/khtml/rendering/render_text.h
index 0cf0cf6..d11741b 100644
--- a/WebCore/khtml/rendering/render_text.h
+++ b/WebCore/khtml/rendering/render_text.h
@@ -139,9 +139,9 @@ public:
     virtual bool isRendered() const { return true; }
 
     virtual void paint(QPainter *, int x, int y, int w, int h,
-                       int tx, int ty, int paintPhase);
+                       int tx, int ty, PaintAction paintAction);
     virtual void paintObject(QPainter *, int x, int y, int w, int h,
-                             int tx, int ty, int paintPhase);
+                             int tx, int ty, PaintAction paintAction);
 
     void deleteSlaves(RenderArena *renderArena = 0);
     virtual void detach(RenderArena* renderArena);

diff --git a/WebCore/khtml/rendering/render_object.h b/WebCore/khtml/rendering/render_object.h
index 4bdd6f4..b3a1aab 100644
--- a/WebCore/khtml/rendering/render_object.h
+++ b/WebCore/khtml/rendering/render_object.h
@@ -52,20 +52,21 @@ class RenderArena;
 #define KHTMLAssert( x )
 #endif
 
-// The painting of a layer occurs in three distinct phases.  Each phase involves
-// a recursive descent into the layer's render objects.
-
-// The first phase is the background phase.  The backgrounds and borders of all blocks
-// are painted.  Inlines are not painted at all.
-#define BACKGROUND_PHASE			0 
-
-// Floats must paint above block backgrounds but entirely below inline content that can
-// overlap them.  
-#define FLOAT_PHASE					1
+/*
+ *	The painting of a layer occurs in three distinct phases.  Each phase involves
+ *	a recursive descent into the layer's render objects. The first phase is the background phase.
+ *	The backgrounds and borders of all blocks are painted.  Inlines are not painted at all.
+ *	Floats must paint above block backgrounds but entirely below inline content that can overlap them.
+ *	In the foreground phase, all inlines are fully painted.  Inline replaced elements will get all
+ *	three phases invoked on them during this phase.
+ */
 
-// In the foreground phase, all inlines are fully painted.  Inline replaced elements will
-// get all three phases invoked on them during this phase.
-#define FOREGROUND_PHASE			2
+typedef enum {
+    PaintActionBackground = 0,
+    PaintActionFloat,
+    PaintActionForeground,
+    PaintActionSelection
+} PaintAction;
 
 namespace DOM {
     class HTMLAreaElementImpl;
@@ -256,11 +257,11 @@ public:
      * (tx|ty) is the calculated position of the parent
      */
     virtual void paint(QPainter *p, int x, int y, int w, int h, int tx, int ty, 
-                       int paintPhase);
+                       PaintAction paintAction);
 
     virtual void paintObject( QPainter */*p*/, int /*x*/, int /*y*/,
                               int /*w*/, int /*h*/, int /*tx*/, int /*ty*/,
-                              int paintPhase /*paintPhase*/) {}
+                              PaintAction paintAction /*paintAction*/) {}
     void paintBorder(QPainter *p, int _tx, int _ty, int w, int h, const RenderStyle* style, bool begin=true, bool end=true);
     void paintOutline(QPainter *p, int _tx, int _ty, int w, int h, const RenderStyle* style);
 
-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list